@@ -43,7 +43,7 @@ DEPEN=0.84
  
 CWD=`pwd`
 # the names of which plugins are to be added to the score file
-SCORE="Packid,Numbers,Soundmemory,Fallingletters,Findsound,Findsound2,Billiard"
+SCORE="Packid,Numbers,Soundmemory,Fallingletters,Findsound,Findsound2,Billiard,Puzzle"
 
 USERID=`id | sed -e 's/).*//; s/^.*(//;'`
 if [ "$USERID" != "root" ]; then
